__title__ = "Trio analysis"
__description__ = "A dialog to create filters for a specific trio analysis"
__long_description__ = ""
__author__ = "Sacha schutz"
__version__ = "1.0.0"
